# junc_utils

[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Build Status](https://travis-ci.org/friend1ws/junc_utils.svg?branch=devel)](https://travis-ci.org/friend1ws/junc_utils)

Utility functions for analyzing splicing junction (generated by STAR, .SJ.out.tab files)

## Dependency

### Python
Python (>= 2.7), `pysam`, `numpy`, `pysam (>= 0.8.1)`,[`annot_utils`](https://github.com/friend1ws/annot_utils) packages.

### Software
tabix, bgzip

## Install

```
git clone https://github.com/friend1ws/junc_utils.git
cd junc_utils
python setup.py build install
```

## Commands

### fitler

filter out splicing junctions outside specified conditions
```
junc_utils filter [-h] [--read_num_thres READ_NUM_THRES]
                         [--overhang_thres OVERHANG_THRES] [--keep_annotated]
                         [--pooled_control_file POOLED_CONTROL_FILE]
                         sample.SJ.out.tab output.txt
```

### annotate

annotate splicing junctions

```
junc_utils annotate [-h] [--grc] [--genome_id {hg19,hg38,mm10}]
                           [--junction_margin JUNCTION_MARGIN]
                           [--exon_margin EXON_MARGIN]
                           sample.SJ.out.tab output.txt
```

### merge_control

merge, compress and index the splicing junction list

```
junc_utils merge_control [-h] [--read_num_thres READ_NUM_THRES]
                                [--overhang_thres OVERHANG_THRES]
                                [--keep_annotated]
                                [--sample_num_thres SAMPLE_NUM_THRES]
                                junc_list.txt output_path
```

### associate

associate junctions with mutations or SVs

```
junc_utils associate [-h] [--grc] [--genome_id {hg19,hg38,mm10}]
                            [--donor_size donor_size]
                            [--acceptor_size acceptor_size]
                            [--reference_genome reference.fa] [--debug]
                            [--mutation_format {vcf,anno}] [--only_dist]
                            [--only_dist_search_margin only_dist_search_margin]
                            [--sv] [--branchpoint]
                            [--branchpoint_size branchpoint_size]
                            annotated_junction.SJ.out.tab mutation.vcf.gz
                            output_file
```

### exonization_pair

get opposite splicing junction to an intronic alternative splice-site junction

```
exonization_pair [-h] [--control_file CONTROL_FILE] [--grc]
                                   [--genome_id {hg19,hg38,mm10}]
                                   [--read_num_thres READ_NUM_THRES]
                                   [--min_new_intron_size MIN_NEW_INTRON_SIZE]
                                   [--max_new_exon_size MAX_NEW_EXON_SIZE]
                                   [--boundary_margin BOUNDARY_MARGIN]
                                   half_exonizaiton_junction sample.SJ.out.tab
                                   output_file
```
